# search
Contains file search functionality, combining find, grep, and sed commands. Internal definitions
of these commands are a work in progress. They are used by search.py in the absence of the commands
on the running system.
